summaryrefslogtreecommitdiff
path: root/src/gui/gtk
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2009-05-10 01:22:08 +0200
committerSebastien Helleu <flashcode@flashtux.org>2009-05-10 01:22:08 +0200
commit57c6478b9184979ad1a09336076b0c07cd7fc56b (patch)
tree60a01bcb7d788217b5c47431c0c1db12dcc053b3 /src/gui/gtk
parent09c42f4cf0787a72a70dd5273da355e522e9fdf5 (diff)
downloadweechat-57c6478b9184979ad1a09336076b0c07cd7fc56b.zip
Add function window_set_title in API (task #9361)
Diffstat (limited to 'src/gui/gtk')
-rw-r--r--src/gui/gtk/gui-gtk-main.c4
-rw-r--r--src/gui/gtk/gui-gtk-window.c16
-rw-r--r--src/gui/gtk/gui-gtk.h3
3 files changed, 7 insertions, 16 deletions
diff --git a/src/gui/gtk/gui-gtk-main.c b/src/gui/gtk/gui-gtk-main.c
index bc5d2d6b7..eff99b2c2 100644
--- a/src/gui/gtk/gui-gtk-main.c
+++ b/src/gui/gtk/gui-gtk-main.c
@@ -192,7 +192,7 @@ gui_main_init ()
gui_current_window = gui_windows;
if (CONFIG_BOOLEAN(config_look_set_title))
- gui_window_title_set ();
+ gui_window_set_title (PACKAGE_NAME " " PACKAGE_VERSION);
}
/* create bar windows for root bars (they were read from config,
@@ -270,7 +270,7 @@ gui_main_end (int clean_exit)
/* reset title */
if (CONFIG_BOOLEAN(config_look_set_title))
- gui_window_title_reset ();
+ gui_window_set_title (NULL);
/* end color */
gui_color_end ();
diff --git a/src/gui/gtk/gui-gtk.h b/src/gui/gtk/gui-gtk.h
index bab6a7960..a7955cf13 100644
--- a/src/gui/gtk/gui-gtk.h
+++ b/src/gui/gtk/gui-gtk.h
@@ -103,7 +103,6 @@ extern void gui_keyboard_flush ();
/* window functions */
extern void gui_window_redraw_buffer (struct t_gui_buffer *buffer);
-extern void gui_window_title_set ();
-extern void gui_window_title_reset ();
+extern void gui_window_set_title (const char *title);
#endif /* gui-gtk.h */
diff --git a/src/gui/gtk/gui-gtk-window.c b/src/gui/gtk/gui-gtk-window.c
index 627448c2e..5d1abe61b 100644
--- a/src/gui/gtk/gui-gtk-window.c
+++ b/src/gui/gtk/gui-gtk-window.c
@@ -786,26 +786,18 @@ gui_window_refresh_screen (int full_refresh)
}
/*
* gui_window_title_set: set terminal title
*/
void
-gui_window_title_set ()
+gui_window_set_title (const char *title)
{
+ (void) title;
+
/* TODO: write this function for Gtk */
}
/*
- * gui_window_title_reset: reset terminal title
- */
-
-void
-gui_window_title_reset ()
-{
- /* This function does nothing in Gtk GUI */
-}
-
-/*
* gui_window_objects_print_log: print Gtk objects infos in log
* (usually for crash dump)
*/
@@ -786,26 +786,18 @@ gui_window_refresh_screen (int full_refresh)
}
/*
- * gui_window_title_set: set terminal title
+ * gui_window_set_title: set terminal title
*/
void